Learn R Programming

covBM (version 0.1.0)

coef.covBM: coef.covBM

Description

This is a method function that extracts the scale coefficient associated with a Brownian motion correlation structure object.

Usage

"coef"(object, unconstrained = TRUE, ...)

Arguments

object
An object of class covBM, inheriting from corStruct.
unconstrained
A logical value. If TRUE the coefficients are returned in unconstrained form (as used in the optimization algorithm). If FALSE the coefficients are returned in "natural" form.
...
Additional arguments (not used by this method).

Examples

Run this code
cov1<-covBM(form=~time|group)
coef(cov1)

Run the code above in your browser using DataLab