This is a method function that extracts the scale coefficient and Hurst parameter
associated with a fractional Brownian motion correlation structure object.
A logical value. If TRUE the coefficients are returned in unconstrained form (as used
in the optimization algorithm). If FALSE the coefficients are returned in "natural" form.