Learn R Programming

covBM (version 0.1.0)

coef.covIOU: coef.covIOU

Description

This is a method function that extracts the perturbation and Alpha parameters associated with an integrated Ornstein-Uhlenbeck (IOU) process correlation structure object.

Usage

"coef"(object, unconstrained = TRUE, ...)

Arguments

object
An object of class covIOU, inheriting from corStruct.
unconstrained
A logical value. If TRUE the coefficients are returned in unconstrained form (as used in the optimization algorithm). If FALSE the coefficients are returned in "natural" form.
...
Additional arguments (not used by this method).

Examples

Run this code
cov3<-covIOU(form=~time|group)
coef(cov3)

Run the code above in your browser using DataLab