Learn R Programming

covBM (version 0.1.0)

corMatrix.covBM: corMatrix.covBM

Description

This method generates a scaled covariance matrix (or list of matrices), for a "covBM" "corStruct" object.

Usage

"corMatrix"(object, covariate = getCovariate(object), ...)

Arguments

object
An object of class covBM, inheriting from corStruct.
covariate
List of covariate vectors, at which values the correlation matrix, or list of correlation matrices, are to be evaluated, as for corMatrix.corStruct.
...
Additional arguments (not used by this method).