Learn R Programming

covBM (version 0.1.0)

covFracBM: covFracBM

Description

This is a constructor function for the "covFracBM" class, representing a fractional Brownian motion component in terms of a continuous variable. The object created is a special type of corStruct.

Usage

covFracBM(value = c(1, 0.5), form = ~1)

Arguments

value
Vector of length 2 providing starting values for optimisation of the scale parameter of fractional Brownian motion process relative to residual error variance and the Hurst parameter, respectively.
form
A one-sided formula of the form ~t|g, where t represents a continuous variable (usually time) and g represents a grouping factor, i.e. with a separate fractional Brownian motion process modelled at each level.

Value

An object of class "covFracBM" and inheriting from "corStruct".

Examples

Run this code
cov2<-covFracBM(form=~time|group)

Run the code above in your browser using DataLab