Learn R Programming

covBM (version 0.1.0)

covIOU: covIOU

Description

This is a constructor function for the "covIOU" class, representing an integrated Ornstein-Uhlenbeck (IOU) process component in terms of a continuous variable. The object created is a special type of corStruct.

Usage

covIOU(value = c(1, 1), form = ~1)

Arguments

value
Vector of length 2 providing starting values for optimisation of the perturbation parameter of integrated Ornstein-Uhlenbeck process relative to residual error variance and the Alpha parameter, respectively.
form
A one-sided formula of the form ~t|g, where t represents a continuous variable (usually time) and g represents a grouping factor, i.e. with a separate integrated Ornstein-Uhlenbeck process modelled at each level.

Value

An object of class "covIOU" and inheriting from "corStruct".

Examples

Run this code
cov3<-covIOU(form=~time|group)

Run the code above in your browser using DataLab