Learn R Programming

covBM (version 0.1.0)

nlmeBM: nlmeBM

Description

This function is a wrapper for nlme.formula that allows Brownian motion, fractional Brownian motion or integrated Ornstein-Uhlenbeck components to be included in non-linear mixed models, with related parameter estimates and confidence intervals returned in their natural parameterisation.

Usage

nlmeBM(model, data, fixed, random, start, covariance = NULL, method = c("ML", "REML"), control = list(), verbose = FALSE)

Arguments

model
This is as specified for nlme.formula.
data
This is as specified for lme.formula.
fixed
This is as specified for lme.formula.
random
This is as specified for nlme.formula.
start
This is as specified for nlme.formula.
covariance
An optional corStruct object describing the within-group covariance structure. In addition to those available in nlme, covBM can be used to incorporate a Brownian motion component, covFracBM can be used to incorporate a fractional Brownian motion component and covIOU can be used to incorporate an integrated Ornstein-Uhlenbeck process in relation to a continuous variable.
method
This is as specified for lme.formula.
control
This is as specified for nlme.formula.
verbose
This is as specified for nlme.formula.

Value

An object of class "nlme" and inheriting from class "lme" representing the non-linear mixed effects model fit.

Examples

Run this code
data(Milk, package="nlme")
Model_fit<- nlmeBM(protein ~ SSasymp(Time, Asym, R0, lrc), data=Milk,
				fixed = Asym + R0 + lrc ~ 1, random = Asym ~ 1|Cow,
				covariance=covFracBM(form=~Time|Cow),
        		start = c(Asym = 3.5, R0 = 4, lrc = -1))

Run the code above in your browser using DataLab