This is a method function that extracts the perturbation and Alpha parameters
associated with an integrated Ornstein-Uhlenbeck (IOU) process correlation structure object.
A logical value. If TRUE the coefficients are returned in unconstrained form (as used
in the optimization algorithm). If FALSE the coefficients are returned in "natural" form.